# DipTrace Generator
![Codecov](https://img.shields.io/codecov/c/github/kolod/DipTrace-Generator?style=for-the-badge)



## Build

## Signed commit
  If your GPG keys aren't copied from Windows to devcontainer use `gpg-disable-keyboxd` command to migrate back to kbx [stackoverflow.com](https://stackoverflow.com/questions/76618338/gpg-keys-not-shared-between-windows-and-visual-studio-code-dev-container-what).
